==> vite-plugin-proxy-0.4.2.tgz: package/src/index.js <==
import { PROJECT_NAME as name } from './constants.js'
import manifestMiddleware from './middlewares/manifest.js'
import proxyMiddleware from './middlewares/proxy.js'
import proxyFrontendsMiddleware from './middlewares/proxy-frontend.js'
import upgradeMiddleware from './middlewares/upgrade.js'
import detectDevServerMiddleware from './middlewares/detect-dev-server.js'
import logger from './logger.js'
import { createHttpProxy } from './httpProxy.js'
import colors from 'picocolors'

export default function ({ proxy, frontends = [], frontendURIs = [], logLevel = 'warn', httpProxy } = {}) {
  logger.level = logLevel

  if (frontends.length && frontendURIs.length) throw new Error('You should only provide either "frontends" or "frontendURIs" configuration.')

  // translate frontendURIs to frontends
  if (frontendURIs.length) {
    logger.warn('Using "frontendURIs" is deprecated. You should switch "frontends" instead.')
    frontends = frontendURIs.map(target => ({ target }))
  }

  // filter frontends without target
  frontends = (frontends || []).filter(frontend => {
    const hasTarget = !!frontend.target
    if (!hasTarget) logger.warn('You have to provide a target for every frontend!')
    return hasTarget
  })

  return {

    enforce: 'pre',

    name,

    async configureServer (server) {
      const { config: { server: serverConfig }, middlewares, httpServer } = server

      if (httpProxy) {
        // overwrite printUrls from vite
        const printUrls = server.printUrls
        server.printUrls = function () {
          const result = printUrls.apply(this, arguments)
          const url = `http://localhost:${httpProxy.port}/`
          console.log(`  > Http proxy: ${colors.cyan(url)}`)
          return result
        }
        createHttpProxy(httpProxy)
      }

      const proxies = Object.entries(proxy || {}).map(([condition, config]) => {
        // prepare proxy config
        const { hostname, protocol, port } = new URL(config.target)
        condition = condition.startsWith('^') ? new RegExp(condition) : condition
        return [condition, {
          ...config,
          hostname,
          protocol,
          port
        }]
      })
      const webProxies = proxies.filter(([c, { ws }]) => ws !== true)
      const wsProxies = proxies.filter(([c, { ws }]) => ws === true)
      frontends.forEach(frontend => {
        frontend.target = frontend.target && new URL(frontend.target)
        if (frontend.path?.startsWith('^')) frontend.path = new RegExp(frontend.path)
      })

      middlewares.use(detectDevServerMiddleware({
        httpServer,
        frontends,
        serverConfig
      }))

      middlewares.use(manifestMiddleware({
        frontends
      }))

      middlewares.use(proxyMiddleware({
        urls: webProxies
      }))

      middlewares.use(proxyFrontendsMiddleware({
        frontends
      }))

      httpServer.on('upgrade', upgradeMiddleware({
        urls: wsProxies
      }))
    }
  }
}

==> vite-plugin-proxy-0.5.0-pre1.tgz: package/src/index.js <==
import { PROJECT_NAME as name } from './constants.js'
import manifestMiddleware from './middlewares/manifest.js'
import proxyMiddleware from './middlewares/proxy.js'
import proxyFrontendsMiddleware from './middlewares/proxy-frontend.js'
import upgradeMiddleware from './middlewares/upgrade.js'
import detectDevServerMiddleware from './middlewares/detect-dev-server.js'
import logger from './logger.js'
import { createHttpProxy } from './httpProxy.js'
import colors from 'picocolors'

export default function ({ proxy, frontends = [], frontendURIs = [], logLevel = 'warn', httpProxy } = {}) {
  let config
  logger.level = logLevel

  if (frontends.length && frontendURIs.length) throw new Error('You should only provide either "frontends" or "frontendURIs" configuration.')

  // translate frontendURIs to frontends
  if (frontendURIs.length) {
    logger.warn('Using "frontendURIs" is deprecated. You should switch "frontends" instead.')
    frontends = frontendURIs.map(target => ({ target }))
  }

  // filter frontends without target
  frontends = (frontends || []).filter(frontend => {
    const hasTarget = !!frontend.target
    if (!hasTarget) logger.warn('You have to provide a target for every frontend!')
    return hasTarget
  })

  return {

    enforce: 'pre',

    name,

    configResolved (c) {
      config = c
    },

    async configureServer (server) {
      const { config: { server: serverConfig }, middlewares, httpServer } = server

      if (httpProxy) {
        // overwrite printUrls from vite
        const printUrls = server.printUrls
        server.printUrls = function () {
          const result = printUrls.apply(this, arguments)
          const url = `http://localhost:${httpProxy.port}/`
          if (config.logLevel === 'info') console.log(`  > Http proxy: ${colors.cyan(url)}`)
          return result
        }
        createHttpProxy(httpProxy)
      }

      const proxies = Object.entries(proxy || {}).map(([condition, config]) => {
        // prepare proxy config
        const { hostname, protocol, port } = new URL(config.target)
        condition = condition.startsWith('^') ? new RegExp(condition) : condition
        return [condition, {
          ...config,
          hostname,
          protocol,
          port
        }]
      })
      const webProxies = proxies.filter(([c, { ws }]) => ws !== true)
      const wsProxies = proxies.filter(([c, { ws }]) => ws === true)
      frontends.forEach(frontend => {
        frontend.target = frontend.target && new URL(frontend.target)
        if (frontend.path?.startsWith('^')) frontend.path = new RegExp(frontend.path)
      })

      middlewares.use(detectDevServerMiddleware({
        httpServer,
        frontends,
        serverConfig
      }))

      middlewares.use(manifestMiddleware({
        base: config.base,
        frontends
      }))

      middlewares.use(proxyMiddleware({
        urls: webProxies
      }))

      middlewares.use(proxyFrontendsMiddleware({
        frontends
      }))

      httpServer.on('upgrade', upgradeMiddleware({
        urls: wsProxies
      }))
    }
  }
}
